from typing import Dict
from huqt_oracle_client.client import OrderSide, OrderTif
from huqt_oracle_client.game import GameInterface, GameSymbolConfig
from random import randint
import asyncio
import time
class NumberGame(GameInterface):
    def __init__(self, url: str, admin_account: str, api_key: str, id: str = None):
        super().__init__(url=url, admin_account=admin_account, api_key=api_key, id=id)
        self.num = randint(10, 20)
    def get_game_name(self):
        return "number"
    def get_initial_usd(self) -> int:
        return 200000
    def get_symbol_config(self) -> Dict[str, GameSymbolConfig]:
        return {
                "NUM": GameSymbolConfig(initial_position=0, lower_bound=-100, upper_bound=100),
                "MUN": GameSymbolConfig(initial_position=0, lower_bound=-100, upper_bound=100)
                }
    def game_body(self):
        response = self.send_public_message("I have a secret number n from 10 and 20 inclusive. NUM will be valued at n and MUN will be valued at 30-n. My bots know the value of n and will trade accordingly.")
        print(response)
        for _ in range(20):
            time.sleep(1)
            # there is a listener that continuously updates the order book
            print(self.orderbook)
            self.bot_order("NUM", size = 10, price = self.num * 100, side = OrderSide.BUY, tif = OrderTif.IOC)
            self.bot_order("NUM", size = 10, price = self.num * 100, side = OrderSide.SELL, tif = OrderTif.IOC)
            self.bot_order("MUN", size = 10, price = (30 - self.num) * 100, side = OrderSide.BUY, tif = OrderTif.IOC)
            self.bot_order("MUN", size = 10, price = (30 - self.num) * 100, side = OrderSide.SELL, tif = OrderTif.IOC)
    def game_settlement(self):
        response = self.send_public_message("NUM was " + str(self.num) + " and MUN was " + str(30-self.num) + ".")
        print(response)
        self.settle_game({
            "NUM": self.num * 100,
            "MUN": (30 - self.num) * 100
        })
    def post_game_processing(self):
        print(self.get_usd_positions())

game = NumberGame(url='huqt-oracle-rust.fly.dev:443', admin_account="account", api_key="sigma", id="FRIGMA")
game.set_accounts(["andrew018.gu@gmail.com"])
asyncio.run(game.run_game())



from enum import Enum
from typing import Dict, List, Optional, Tuple
import grpc
import certifi
from .protos import exchange_pb2 as exchange
from .protos import exchange_pb2_grpc
from .protos import marketdata_pb2 as marketdata
from .protos import marketdata_pb2_grpc
from .protos import admin_pb2
from .protos import admin_pb2_grpc

from dataclasses import dataclass

@dataclass
class Response:
    status: str
    message: str
    
@dataclass
class PublicOrder:
    symbol: str
    size: int
    price: int
    

@dataclass
class ResponseList:
    response: Optional[Response]
    order_responses: List[Response]

class OrderSide(Enum):
    BUY = 0
    SELL = 1
    
class OrderTif(Enum):
    DAY = 0
    IOC = 1

def get_channel(url, secure):
    # Load the CA bundle from certifi
    if not secure:
        return grpc.insecure_channel(url)
    else:
        with open(certifi.where(), "rb") as f:
            trusted_certs = f.read()
        # Create secure channel credentials using the trusted certificates
        credentials = grpc.ssl_channel_credentials(root_certificates=trusted_certs)
        return grpc.secure_channel(url, credentials)

def get_async_channel(url, secure):
    # Load the CA bundle from certifi
    if not secure:
        return grpc.aio.insecure_channel(url)
    else:
        with open(certifi.where(), "rb") as f:
            trusted_certs = f.read()
        # Create secure channel credentials using the trusted certificates
        credentials = grpc.ssl_channel_credentials(root_certificates=trusted_certs)
        return grpc.aio.secure_channel(url, credentials)
        

class Trader():
    def __init__(self, account, api_key, url, secure = True):
        self.channel = get_channel(url, secure)
        self.stub = exchange_pb2_grpc.ExchangeStub(self.channel)
        self.api_key = api_key
        self.account = account
    
    def submit_order(self, symbol: str, size: int, price: int, side: OrderSide, tif: OrderTif) -> Response:
        return submit_order(self.stub, symbol, size, price, side, tif, self.account, self.api_key)
    
    def cancel_order(self, order_id: str) -> Response:
        return cancel_order(self.stub, order_id, self.account, self.api_key)
    
    def cancel_orders(self, order_ids: List[str]) -> ResponseList:
        return cancel_orders(self.stub, order_ids, self.account, self.api_key)

class Listener():
    def __init__(self, account, api_key, url, secure = True):
        self.channel = get_async_channel(url, secure)
        self.stub = marketdata_pb2_grpc.MarketDataServiceStub(self.channel)
        self.api_key = api_key
        self.account = account
    
    async def listen(self):
        await listen(self.stub, self.account, self.api_key)
        
class Admin():
    def __init__(self, account, api_key, url, secure = True):
        self.channel = get_channel(url, secure)
        self.stub = admin_pb2_grpc.AdminServiceStub(self.channel)
        self.api_key = api_key
        self.account = account
    
    def add_partition(self, partition: str):
        return add_partition(
            stub=self.stub,
            partition=partition,
            account=self.account,
            api_key=self.api_key
        )

    def add_account_type_to_partition(self, partition: str, account_type: str):
        return add_account_type_to_partition(
            stub=self.stub,
            partition=partition,
            account_type=account_type,
            account=self.account,
            api_key=self.api_key
        )

    def add_symbol(self, partition: str, id: str, display_name: str):
        return add_symbol(
            stub=self.stub,
            partition=partition,
            id=id,
            name=display_name,
            account=self.account,
            api_key=self.api_key
        )

    def start_partition(self, partition: str):
        return start_partition(
            stub=self.stub,
            partition=partition,
            account=self.account,
            api_key=self.api_key
        )

    def pause_partition(self, partition: str):
        return pause_partition(
            stub=self.stub,
            partition=partition,
            account=self.account,
            api_key=self.api_key
        )

    # Analogues for the remaining Admin RPC functions:

    def end_partition(self, partition: str):
        return end_partition(
            stub=self.stub,
            partition=partition,
            account=self.account,
            api_key=self.api_key
        )

    def settle_partition(self, partition: str, settle_prices: Dict[str, int]):
        """
        settle_prices: Dict mapping symbol to price
        """
        prices = []
        for key in settle_prices:
            prices.append((key, str(settle_prices[key])))
        return settle_partition(
            stub=self.stub,
            partition=partition,
            settle_prices=prices,
            account=self.account,
            api_key=self.api_key
        )

    def open_exchange(self):
        return open_exchange(
            stub=self.stub,
            account=self.account,
            api_key=self.api_key
        )

    def close_exchange(self):
        return close_exchange(
            stub=self.stub,
            account=self.account,
            api_key=self.api_key
        )

    def set_position(self, account: str, symbol: str, value: int):
        return set_position(
            stub=self.stub,
            account=account,
            symbol=symbol,
            value=str(value),
            admin_account=self.account,
            api_key=self.api_key
        )

    def adjust_position(self, account: str, symbol: str, value: int):
        return adjust_position(
            stub=self.stub,
            account=account,
            symbol=symbol,
            value=str(value),
            admin_account=self.account,
            api_key=self.api_key
        )

    def set_account_fee(self, account: str, fee: int):
        return set_account_fee(
            stub=self.stub,
            account=account,
            fee=str(fee),
            admin_account=self.account,
            api_key=self.api_key
        )

    def set_enable_fee(self, symbol: str, enable: bool):
        return set_enable_fee(
            stub=self.stub,
            symbol=symbol,
            enable=enable,
            account=self.account,
            api_key=self.api_key
        )
    
    def set_position_limits(self, account: str, symbol: str, lower_bound: float, upper_bound: float):
        if lower_bound == -float('inf'):
            lower_bound = "-Infinity"
        else:
            lower_bound = int(lower_bound)
        if upper_bound == float('inf'):
            upper_bound = "Infinity"
        else:
            upper_bound = int(upper_bound)
        return set_position_limits(
            stub=self.stub,
            account=account,
            symbol=symbol,
            lower_bound=str(lower_bound),
            upper_bound=str(upper_bound),
            admin_account=self.account,
            api_key=self.api_key
        )

    def register_named_account(self, account: str):
        return register_named_account(
            stub=self.stub,
            account=account,
            admin_account=self.account,
            api_key=self.api_key
        )
    
    def register_bot_account(self, account: str):
        return register_bot_account(
            stub=self.stub,
            account=account,
            admin_account=self.account,
            api_key=self.api_key
        )
    
    def send_private_message(self, account: str, message: str):
        return send_private_message(
            stub=self.stub,
            account=account,
            message=message,
            admin_account=self.account,
            api_key=self.api_key
        )
    def send_public_message(self, partition: str, message: str):
        return send_public_message(
            stub=self.stub,
            partition=partition,
            message=message,
            admin_account=self.account,
            api_key=self.api_key
        )
    def get_position(self, account: str, symbol: str) -> int:
        return get_position(
            stub=self.stub,
            account=account,
            symbol=symbol,
            admin_account=self.account,
            api_key=self.api_key
        )

        
    

def submit_order(stub: exchange_pb2_grpc.ExchangeStub, symbol: str, size: int, price: int, side: OrderSide, tif: OrderTif, account: str, api_key: str) -> Response: 
    request = exchange.OrderRequest(symbol = symbol, logging = "", size = str(size), price = str(price), side = side.value, tif = tif.value, account = account, api_key = api_key)
    response = stub.SubmitOrder(request)
    return Response(status = response.status, message = response.message)
    

    
def cancel_order(stub: exchange_pb2_grpc.ExchangeStub, order_id: str, account: str, api_key: str) -> Response:
    request = exchange.CancelOrderRequest(order_id = order_id, account = account, api_key = api_key)
    response = stub.CancelOrder(request)
    return Response(status = response.status, message = response.message)

def cancel_orders(stub: exchange_pb2_grpc.ExchangeStub, order_ids: List[str], account: str, api_key: str) -> ResponseList:
    request = exchange.CancelOrdersRequest(order_ids = order_ids, account = account, api_key = api_key)
    response = stub.CancelOrders(request)
    if response.HasField("response"):
        return ResponseList(response = response.response, order_responses = response.order_responses)
    else:
        return ResponseList(response = None, order_responses = response.order_responses)
    
def add_account_type_to_partition(
    stub: admin_pb2_grpc.AdminServiceStub, 
    partition: str, 
    account_type: str, 
    account: str, 
    api_key: str
) -> Response:
    auth = admin_pb2.AdminAuthInfo(account=account, api_key=api_key)
    request = admin_pb2.AddAccountTypeToPartitionRequest(
        partition=partition, 
        account_type=account_type, 
        auth=auth
    )
    response = stub.AddAccountTypeToPartition(request)
    return Response(status=response.status, message=response.message)

def end_partition(
    stub: admin_pb2_grpc.AdminServiceStub, 
    partition: str, 
    account: str, 
    api_key: str
) -> Response:
    auth = admin_pb2.AdminAuthInfo(account=account, api_key=api_key)
    request = admin_pb2.EndPartitionRequest(
        partition=partition, 
        auth=auth
    )
    response = stub.EndPartition(request)
    return Response(status=response.status, message=response.message)

def pause_partition(
    stub: admin_pb2_grpc.AdminServiceStub, 
    partition: str, 
    account: str, 
    api_key: str
) -> Response:
    auth = admin_pb2.AdminAuthInfo(account=account, api_key=api_key)
    request = admin_pb2.PausePartitionRequest(
        partition=partition, 
        auth=auth
    )
    response = stub.PausePartition(request)
    return Response(status=response.status, message=response.message)

def start_partition(
    stub: admin_pb2_grpc.AdminServiceStub, 
    partition: str, 
    account: str, 
    api_key: str
) -> Response:
    auth = admin_pb2.AdminAuthInfo(account=account, api_key=api_key)
    request = admin_pb2.StartPartitionRequest(
        partition=partition, 
        auth=auth
    )
    response = stub.StartPartition(request)
    return Response(status=response.status, message=response.message)

def settle_partition(
    stub: admin_pb2_grpc.AdminServiceStub, 
    partition: str, 
    settle_prices: List[Tuple[str, str]], 
    account: str, 
    api_key: str
) -> Response:
    """
    settle_prices: list of tuples (symbol, price)
    """
    auth = admin_pb2.AdminAuthInfo(account=account, api_key=api_key)
    settlements = [
        admin_pb2.Settlement(symbol=symbol, price=price)
        for symbol, price in settle_prices
    ]
    request = admin_pb2.SettlePartitionRequest(
        partition=partition, 
        settle_prices=settlements, 
        auth=auth
    )
    response = stub.SettlePartition(request)
    return Response(status=response.status, message=response.message)

def open_exchange(
    stub: admin_pb2_grpc.AdminServiceStub, 
    account: str, 
    api_key: str
) -> Response:
    auth = admin_pb2.AdminAuthInfo(account=account, api_key=api_key)
    request = admin_pb2.OpenExchangeRequest(auth=auth)
    response = stub.OpenExchange(request)
    return Response(status=response.status, message=response.message)

def close_exchange(
    stub: admin_pb2_grpc.AdminServiceStub, 
    account: str, 
    api_key: str
) -> Response:
    auth = admin_pb2.AdminAuthInfo(account=account, api_key=api_key)
    request = admin_pb2.CloseExchangeRequest(auth=auth)
    response = stub.CloseExchange(request)
    return Response(status=response.status, message=response.message)

def add_symbol(
    stub: admin_pb2_grpc.AdminServiceStub, 
    partition: str, 
    id: str, 
    name: str, 
    account: str, 
    api_key: str
) -> Response:
    auth = admin_pb2.AdminAuthInfo(account=account, api_key=api_key)
    request = admin_pb2.AddSymbolRequest(
        partition=partition, 
        id=id, 
        name=name, 
        auth=auth
    )
    response = stub.AddSymbol(request)
    return Response(status=response.status, message=response.message)

def set_position(
    stub: admin_pb2_grpc.AdminServiceStub, 
    account: str, 
    symbol: str, 
    value: str, 
    admin_account: str,
    api_key: str
) -> Response:
    auth = admin_pb2.AdminAuthInfo(account=admin_account, api_key=api_key)
    request = admin_pb2.SetPositionRequest(
        account=account, 
        symbol=symbol, 
        value=value, 
        auth=auth
    )
    response = stub.SetPosition(request)
    return Response(status=response.status, message=response.message)

def adjust_position(
    stub: admin_pb2_grpc.AdminServiceStub, 
    account: str, 
    symbol: str, 
    value: str, 
    admin_account: str,
    api_key: str
) -> Response:
    auth = admin_pb2.AdminAuthInfo(account=admin_account, api_key=api_key)
    request = admin_pb2.AdjustPositionRequest(
        account=account, 
        symbol=symbol, 
        value=value, 
        auth=auth
    )
    response = stub.AdjustPosition(request)
    return Response(status=response.status, message=response.message)

def set_account_fee(
    stub: admin_pb2_grpc.AdminServiceStub, 
    account: str, 
    fee: str, 
    admin_account: str,
    api_key: str
) -> Response:
    auth = admin_pb2.AdminAuthInfo(account=admin_account, api_key=api_key)
    request = admin_pb2.SetAccountFeeRequest(
        account=account, 
        fee=fee, 
        auth=auth
    )
    response = stub.SetAccountFee(request)
    return Response(status=response.status, message=response.message)

def set_enable_fee(
    stub: admin_pb2_grpc.AdminServiceStub, 
    symbol: str, 
    enable: bool, 
    account: str, 
    api_key: str
) -> Response:
    auth = admin_pb2.AdminAuthInfo(account=account, api_key=api_key)
    request = admin_pb2.SetEnableFeeRequest(
        symbol=symbol, 
        enable=enable, 
        auth=auth
    )
    response = stub.SetEnableFee(request)
    return Response(status=response.status, message=response.message)

def set_position_limits(
    stub: admin_pb2_grpc.AdminServiceStub, 
    account: str, 
    symbol: str, 
    lower_bound: str, 
    upper_bound: str, 
    admin_account: str,
    api_key: str
) -> Response:
    auth = admin_pb2.AdminAuthInfo(account=admin_account, api_key=api_key)
    request = admin_pb2.SetPositionLimitsRequest(
        account=account, 
        symbol=symbol, 
        lower_bound=lower_bound, 
        upper_bound=upper_bound, 
        auth=auth
    )
    response = stub.SetPositionLimits(request)
    return Response(status=response.status, message=response.message)

def register_named_account(
    stub: admin_pb2_grpc.AdminServiceStub, 
    account: str,
    admin_account: str, 
    api_key: str
) -> Response:
    auth = admin_pb2.AdminAuthInfo(account=admin_account, api_key=api_key)
    request = admin_pb2.RegisterNamedAccountRequest(
        account=account, 
        auth=auth
    )
    response = stub.RegisterNamedAccount(request)
    return Response(status=response.status, message=response.message)

def register_bot_account(
    stub: admin_pb2_grpc.AdminServiceStub, 
    account: str,
    admin_account: str, 
    api_key: str
) -> Response:
    auth = admin_pb2.AdminAuthInfo(account=admin_account, api_key=api_key)
    request = admin_pb2.RegisterBotAccountRequest(
        account=account, 
        auth=auth
    )
    response = stub.RegisterBotAccount(request)
    return Response(status=response.status, message=response.message)

def add_partition(
    stub: admin_pb2_grpc.AdminServiceStub, 
    partition: str, 
    account: str, 
    api_key: str
) -> Response:
    auth = admin_pb2.AdminAuthInfo(account=account, api_key=api_key)
    request = admin_pb2.AddPartitionRequest(
        partition=partition, 
        auth=auth
    )
    response = stub.AddPartition(request)
    return Response(status=response.status, message=response.message)

def send_private_message(
    stub: admin_pb2_grpc.AdminServiceStub, 
    account: str, 
    message: str,
    admin_account: str,
    api_key: str
) -> Response:
    auth = admin_pb2.AdminAuthInfo(account=admin_account, api_key=api_key)
    request = admin_pb2.SendPrivateMessageRequest(
        account=account, 
        message=message,
        auth=auth
    )
    response = stub.SendPrivateMessage(request)
    return Response(status=response.status, message=response.message)

def send_public_message(
    stub: admin_pb2_grpc.AdminServiceStub, 
    partition: str, 
    message: str,
    admin_account: str,
    api_key: str
) -> Response:
    auth = admin_pb2.AdminAuthInfo(account=admin_account, api_key=api_key)
    request = admin_pb2.SendPublicMessageRequest(
        partition=partition, 
        message=message,
        auth=auth
    )
    response = stub.SendPublicMessage(request)
    return Response(status=response.status, message=response.message)

def get_position(
    stub: admin_pb2_grpc.AdminServiceStub, 
    account: str, 
    symbol: str,
    admin_account: str,
    api_key: str
) -> int:
    auth = admin_pb2.AdminAuthInfo(account=admin_account, api_key=api_key)
    request = admin_pb2.GetPositionRequest(
        account=account, 
        symbol=symbol,
        auth=auth
    )
    response = stub.GetPosition(request)
    return int(response.message)

    
async def listen(stub: marketdata_pb2_grpc.MarketDataServiceStub, account: str, api_key: str):
    # Build your subscription request. Adjust fields as needed.
    request = marketdata.SubscriptionRequest(
        api_key=api_key,
        account=account
    )
    
    # Calling the streaming RPC method.
    stream = stub.StreamStatus(request)
    
    # Iterate over the stream of responses.
    async for market_data in stream:
        print("Received market data:", market_data)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'admin.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import exchange_pb2 as exchange__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x61\x64min.proto\x12\x05\x61\x64min\x1a\x0e\x65xchange.proto\"o\n AddAccountTypeToPartitionRequest\x12\x11\n\tpartition\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_type\x18\x02 \x01(\t\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"L\n\x13\x45ndPartitionRequest\x12\x11\n\tpartition\x18\x01 \x01(\t\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"N\n\x15PausePartitionRequest\x12\x11\n\tpartition\x18\x01 \x01(\t\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"N\n\x15StartPartitionRequest\x12\x11\n\tpartition\x18\x01 \x01(\t\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"+\n\nSettlement\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\r\n\x05price\x18\x02 \x01(\t\"y\n\x16SettlePartitionRequest\x12\x11\n\tpartition\x18\x01 \x01(\t\x12(\n\rsettle_prices\x18\x02 \x03(\x0b\x32\x11.admin.Settlement\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"9\n\x13OpenExchangeRequest\x12\"\n\x04\x61uth\x18\x01 \x01(\x0b\x32\x14.admin.AdminAuthInfo\":\n\x14\x43loseExchangeRequest\x12\"\n\x04\x61uth\x18\x01 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"c\n\x10\x41\x64\x64SymbolRequest\x12\x11\n\tpartition\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\"\n\x04\x61uth\x18\x04 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"h\n\x12SetPositionRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\"\n\x04\x61uth\x18\x04 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"k\n\x15\x41\x64justPositionRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\"\n\x04\x61uth\x18\x04 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"X\n\x14SetAccountFeeRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x0b\n\x03\x66\x65\x65\x18\x02 \x01(\t\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"Y\n\x13SetEnableFeeRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"\x89\x01\n\x18SetPositionLimitsRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x13\n\x0blower_bound\x18\x03 \x01(\t\x12\x13\n\x0bupper_bound\x18\x04 \x01(\t\x12\"\n\x04\x61uth\x18\x05 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"R\n\x1bRegisterNamedAccountRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"P\n\x19RegisterBotAccountRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"L\n\x13\x41\x64\x64PartitionRequest\x12\x11\n\tpartition\x18\x01 \x01(\t\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"1\n\rAdminAuthInfo\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t\"a\n\x19SendPrivateMessageRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"b\n\x18SendPublicMessageRequest\x12\x11\n\tpartition\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"Y\n\x12GetPositionRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"E\n\x11UpsertUserRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"\\\n\x17\x41\x64\x64UserToAccountRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x02 \x01(\t\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"L\n\x18\x43learUserAccountsRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"a\n\x1c\x44\x65leteUserFromAccountRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x02 \x01(\t\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.admin.AdminAuthInfo2\xf1\r\n\x0c\x41\x64minService\x12_\n\x19\x41\x64\x64\x41\x63\x63ountTypeToPartition\x12\'.admin.AddAccountTypeToPartitionRequest\x1a\x19.exchange.GenericResponse\x12\x45\n\x0c\x45ndPartition\x12\x1a.admin.EndPartitionRequest\x1a\x19.exchange.GenericResponse\x12I\n\x0ePausePartition\x12\x1c.admin.PausePartitionRequest\x1a\x19.exchange.GenericResponse\x12I\n\x0eStartPartition\x12\x1c.admin.StartPartitionRequest\x1a\x19.exchange.GenericResponse\x12K\n\x0fSettlePartition\x12\x1d.admin.SettlePartitionRequest\x1a\x19.exchange.GenericResponse\x12\x45\n\x0cOpenExchange\x12\x1a.admin.OpenExchangeRequest\x1a\x19.exchange.GenericResponse\x12G\n\rCloseExchange\x12\x1b.admin.CloseExchangeRequest\x1a\x19.exchange.GenericResponse\x12?\n\tAddSymbol\x12\x17.admin.AddSymbolRequest\x1a\x19.exchange.GenericResponse\x12\x43\n\x0bSetPosition\x12\x19.admin.SetPositionRequest\x1a\x19.exchange.GenericResponse\x12I\n\x0e\x41\x64justPosition\x12\x1c.admin.AdjustPositionRequest\x1a\x19.exchange.GenericResponse\x12G\n\rSetAccountFee\x12\x1b.admin.SetAccountFeeRequest\x1a\x19.exchange.GenericResponse\x12\x45\n\x0cSetEnableFee\x12\x1a.admin.SetEnableFeeRequest\x1a\x19.exchange.GenericResponse\x12O\n\x11SetPositionLimits\x12\x1f.admin.SetPositionLimitsRequest\x1a\x19.exchange.GenericResponse\x12U\n\x14RegisterNamedAccount\x12\".admin.RegisterNamedAccountRequest\x1a\x19.exchange.GenericResponse\x12Q\n\x12RegisterBotAccount\x12 .admin.RegisterBotAccountRequest\x1a\x19.exchange.GenericResponse\x12\x45\n\x0c\x41\x64\x64Partition\x12\x1a.admin.AddPartitionRequest\x1a\x19.exchange.GenericResponse\x12Q\n\x12SendPrivateMessage\x12 .admin.SendPrivateMessageRequest\x1a\x19.exchange.GenericResponse\x12O\n\x11SendPublicMessage\x12\x1f.admin.SendPublicMessageRequest\x1a\x19.exchange.GenericResponse\x12\x43\n\x0bGetPosition\x12\x19.admin.GetPositionRequest\x1a\x19.exchange.GenericResponse\x12\x41\n\nUpsertUser\x12\x18.admin.UpsertUserRequest\x1a\x19.exchange.GenericResponse\x12M\n\x10\x41\x64\x64UserToAccount\x12\x1e.admin.AddUserToAccountRequest\x1a\x19.exchange.GenericResponse\x12O\n\x11\x43learUserAccounts\x12\x1f.admin.ClearUserAccountsRequest\x1a\x19.exchange.GenericResponse\x12W\n\x15\x44\x65leteUserFromAccount\x12#.admin.DeleteUserFromAccountRequest\x1a\x19.exchange.GenericResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ADDACCOUNTTYPETOPARTITIONREQUEST']._serialized_start=38
  _globals['_ADDACCOUNTTYPETOPARTITIONREQUEST']._serialized_end=149
  _globals['_ENDPARTITIONREQUEST']._serialized_start=151
  _globals['_ENDPARTITIONREQUEST']._serialized_end=227
  _globals['_PAUSEPARTITIONREQUEST']._serialized_start=229
  _globals['_PAUSEPARTITIONREQUEST']._serialized_end=307
  _globals['_STARTPARTITIONREQUEST']._serialized_start=309
  _globals['_STARTPARTITIONREQUEST']._serialized_end=387
  _globals['_SETTLEMENT']._serialized_start=389
  _globals['_SETTLEMENT']._serialized_end=432
  _globals['_SETTLEPARTITIONREQUEST']._serialized_start=434
  _globals['_SETTLEPARTITIONREQUEST']._serialized_end=555
  _globals['_OPENEXCHANGEREQUEST']._serialized_start=557
  _globals['_OPENEXCHANGEREQUEST']._serialized_end=614
  _globals['_CLOSEEXCHANGEREQUEST']._serialized_start=616
  _globals['_CLOSEEXCHANGEREQUEST']._serialized_end=674
  _globals['_ADDSYMBOLREQUEST']._serialized_start=676
  _globals['_ADDSYMBOLREQUEST']._serialized_end=775
  _globals['_SETPOSITIONREQUEST']._serialized_start=777
  _globals['_SETPOSITIONREQUEST']._serialized_end=881
  _globals['_ADJUSTPOSITIONREQUEST']._serialized_start=883
  _globals['_ADJUSTPOSITIONREQUEST']._serialized_end=990
  _globals['_SETACCOUNTFEEREQUEST']._serialized_start=992
  _globals['_SETACCOUNTFEEREQUEST']._serialized_end=1080
  _globals['_SETENABLEFEEREQUEST']._serialized_start=1082
  _globals['_SETENABLEFEEREQUEST']._serialized_end=1171
  _globals['_SETPOSITIONLIMITSREQUEST']._serialized_start=1174
  _globals['_SETPOSITIONLIMITSREQUEST']._serialized_end=1311
  _globals['_REGISTERNAMEDACCOUNTREQUEST']._serialized_start=1313
  _globals['_REGISTERNAMEDACCOUNTREQUEST']._serialized_end=1395
  _globals['_REGISTERBOTACCOUNTREQUEST']._serialized_start=1397
  _globals['_REGISTERBOTACCOUNTREQUEST']._serialized_end=1477
  _globals['_ADDPARTITIONREQUEST']._serialized_start=1479
  _globals['_ADDPARTITIONREQUEST']._serialized_end=1555
  _globals['_ADMINAUTHINFO']._serialized_start=1557
  _globals['_ADMINAUTHINFO']._serialized_end=1606
  _globals['_SENDPRIVATEMESSAGEREQUEST']._serialized_start=1608
  _globals['_SENDPRIVATEMESSAGEREQUEST']._serialized_end=1705
  _globals['_SENDPUBLICMESSAGEREQUEST']._serialized_start=1707
  _globals['_SENDPUBLICMESSAGEREQUEST']._serialized_end=1805
  _globals['_GETPOSITIONREQUEST']._serialized_start=1807
  _globals['_GETPOSITIONREQUEST']._serialized_end=1896
  _globals['_UPSERTUSERREQUEST']._serialized_start=1898
  _globals['_UPSERTUSERREQUEST']._serialized_end=1967
  _globals['_ADDUSERTOACCOUNTREQUEST']._serialized_start=1969
  _globals['_ADDUSERTOACCOUNTREQUEST']._serialized_end=2061
  _globals['_CLEARUSERACCOUNTSREQUEST']._serialized_start=2063
  _globals['_CLEARUSERACCOUNTSREQUEST']._serialized_end=2139
  _globals['_DELETEUSERFROMACCOUNTREQUEST']._serialized_start=2141
  _globals['_DELETEUSERFROMACCOUNTREQUEST']._serialized_end=2238
  _globals['_ADMINSERVICE']._serialized_start=2241
  _globals['_ADMINSERVICE']._serialized_end=4018
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import exchange_pb2 as exchange__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2

GRPC_GENERATED_VERSION = '1.71.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in exchange_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class ExchangeStub(object):
    """The exchange service definition.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SubmitOrder = channel.unary_unary(
                '/exchange.Exchange/SubmitOrder',
                request_serializer=exchange__pb2.OrderRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.CancelOrder = channel.unary_unary(
                '/exchange.Exchange/CancelOrder',
                request_serializer=exchange__pb2.CancelOrderRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.CancelOrders = channel.unary_unary(
                '/exchange.Exchange/CancelOrders',
                request_serializer=exchange__pb2.CancelOrdersRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponseList.FromString,
                _registered_method=True)
        self.GetPositions = channel.unary_unary(
                '/exchange.Exchange/GetPositions',
                request_serializer=exchange__pb2.GetPositionsRequest.SerializeToString,
                response_deserializer=exchange__pb2.PositionStatus.FromString,
                _registered_method=True)
        self.GetExchangeStatus = channel.unary_unary(
                '/exchange.Exchange/GetExchangeStatus',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)


class ExchangeServicer(object):
    """The exchange service definition.
    """

    def SubmitOrder(self, request, context):
        """Submit a new order.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelOrder(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelOrders(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPositions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExchangeStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ExchangeServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SubmitOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.SubmitOrder,
                    request_deserializer=exchange__pb2.OrderRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'CancelOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelOrder,
                    request_deserializer=exchange__pb2.CancelOrderRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'CancelOrders': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelOrders,
                    request_deserializer=exchange__pb2.CancelOrdersRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponseList.SerializeToString,
            ),
            'GetPositions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPositions,
                    request_deserializer=exchange__pb2.GetPositionsRequest.FromString,
                    response_serializer=exchange__pb2.PositionStatus.SerializeToString,
            ),
            'GetExchangeStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExchangeStatus,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'exchange.Exchange', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('exchange.Exchange', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Exchange(object):
    """The exchange service definition.
    """

    @staticmethod
    def SubmitOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/exchange.Exchange/SubmitOrder',
            exchange__pb2.OrderRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CancelOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/exchange.Exchange/CancelOrder',
            exchange__pb2.CancelOrderRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CancelOrders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/exchange.Exchange/CancelOrders',
            exchange__pb2.CancelOrdersRequest.SerializeToString,
            exchange__pb2.GenericResponseList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPositions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/exchange.Exchange/GetPositions',
            exchange__pb2.GetPositionsRequest.SerializeToString,
            exchange__pb2.PositionStatus.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetExchangeStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/exchange.Exchange/GetExchangeStatus',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: exchange.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'exchange.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x65xchange.proto\x12\x08\x65xchange\x1a\x1bgoogle/protobuf/empty.proto\"\xb2\x01\n\x0cOrderRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x0f\n\x07logging\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\t\x12\r\n\x05price\x18\x04 \x01(\t\x12!\n\x04side\x18\x05 \x01(\x0e\x32\x13.exchange.OrderSide\x12\x1f\n\x03tif\x18\x06 \x01(\x0e\x32\x12.exchange.OrderTif\x12\x0f\n\x07\x61\x63\x63ount\x18\x07 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x08 \x01(\t\"H\n\x12\x43\x61ncelOrderRequest\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x02 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x03 \x01(\t\"2\n\x0fGenericResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\"J\n\x13\x43\x61ncelOrdersRequest\x12\x11\n\torder_ids\x18\x01 \x03(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x02 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x03 \x01(\t\"v\n\x13GenericResponseList\x12+\n\x08response\x18\x01 \x01(\x0b\x32\x19.exchange.GenericResponse\x12\x32\n\x0forder_responses\x18\x02 \x03(\x0b\x32\x19.exchange.GenericResponse\"7\n\x13GetPositionsRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t\"V\n\x08Position\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08position\x18\x02 \x01(\t\x12\x13\n\x0blower_bound\x18\x03 \x01(\t\x12\x13\n\x0bupper_bound\x18\x04 \x01(\t\"7\n\x0ePositionStatus\x12%\n\tpositions\x18\x01 \x03(\x0b\x32\x12.exchange.Position*\x1e\n\tOrderSide\x12\x07\n\x03\x42uy\x10\x00\x12\x08\n\x04Sell\x10\x01*\x1c\n\x08OrderTif\x12\x07\n\x03\x44\x61y\x10\x00\x12\x07\n\x03Ioc\x10\x01\x32\xf3\x02\n\x08\x45xchange\x12@\n\x0bSubmitOrder\x12\x16.exchange.OrderRequest\x1a\x19.exchange.GenericResponse\x12\x46\n\x0b\x43\x61ncelOrder\x12\x1c.exchange.CancelOrderRequest\x1a\x19.exchange.GenericResponse\x12L\n\x0c\x43\x61ncelOrders\x12\x1d.exchange.CancelOrdersRequest\x1a\x1d.exchange.GenericResponseList\x12G\n\x0cGetPositions\x12\x1d.exchange.GetPositionsRequest\x1a\x18.exchange.PositionStatus\x12\x46\n\x11GetExchangeStatus\x12\x16.google.protobuf.Empty\x1a\x19.exchange.GenericResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ORDERSIDE']._serialized_start=762
  _globals['_ORDERSIDE']._serialized_end=792
  _globals['_ORDERTIF']._serialized_start=794
  _globals['_ORDERTIF']._serialized_end=822
  _globals['_ORDERREQUEST']._serialized_start=58
  _globals['_ORDERREQUEST']._serialized_end=236
  _globals['_CANCELORDERREQUEST']._serialized_start=238
  _globals['_CANCELORDERREQUEST']._serialized_end=310
  _globals['_GENERICRESPONSE']._serialized_start=312
  _globals['_GENERICRESPONSE']._serialized_end=362
  _globals['_CANCELORDERSREQUEST']._serialized_start=364
  _globals['_CANCELORDERSREQUEST']._serialized_end=438
  _globals['_GENERICRESPONSELIST']._serialized_start=440
  _globals['_GENERICRESPONSELIST']._serialized_end=558
  _globals['_GETPOSITIONSREQUEST']._serialized_start=560
  _globals['_GETPOSITIONSREQUEST']._serialized_end=615
  _globals['_POSITION']._serialized_start=617
  _globals['_POSITION']._serialized_end=703
  _globals['_POSITIONSTATUS']._serialized_start=705
  _globals['_POSITIONSTATUS']._serialized_end=760
  _globals['_EXCHANGE']._serialized_start=825
  _globals['_EXCHANGE']._serialized_end=1196
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import admin_pb2 as admin__pb2
from . import exchange_pb2 as exchange__pb2

GRPC_GENERATED_VERSION = '1.71.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in admin_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class AdminServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddAccountTypeToPartition = channel.unary_unary(
                '/admin.AdminService/AddAccountTypeToPartition',
                request_serializer=admin__pb2.AddAccountTypeToPartitionRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.EndPartition = channel.unary_unary(
                '/admin.AdminService/EndPartition',
                request_serializer=admin__pb2.EndPartitionRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.PausePartition = channel.unary_unary(
                '/admin.AdminService/PausePartition',
                request_serializer=admin__pb2.PausePartitionRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.StartPartition = channel.unary_unary(
                '/admin.AdminService/StartPartition',
                request_serializer=admin__pb2.StartPartitionRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.SettlePartition = channel.unary_unary(
                '/admin.AdminService/SettlePartition',
                request_serializer=admin__pb2.SettlePartitionRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.OpenExchange = channel.unary_unary(
                '/admin.AdminService/OpenExchange',
                request_serializer=admin__pb2.OpenExchangeRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.CloseExchange = channel.unary_unary(
                '/admin.AdminService/CloseExchange',
                request_serializer=admin__pb2.CloseExchangeRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.AddSymbol = channel.unary_unary(
                '/admin.AdminService/AddSymbol',
                request_serializer=admin__pb2.AddSymbolRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.SetPosition = channel.unary_unary(
                '/admin.AdminService/SetPosition',
                request_serializer=admin__pb2.SetPositionRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.AdjustPosition = channel.unary_unary(
                '/admin.AdminService/AdjustPosition',
                request_serializer=admin__pb2.AdjustPositionRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.SetAccountFee = channel.unary_unary(
                '/admin.AdminService/SetAccountFee',
                request_serializer=admin__pb2.SetAccountFeeRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.SetEnableFee = channel.unary_unary(
                '/admin.AdminService/SetEnableFee',
                request_serializer=admin__pb2.SetEnableFeeRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.SetPositionLimits = channel.unary_unary(
                '/admin.AdminService/SetPositionLimits',
                request_serializer=admin__pb2.SetPositionLimitsRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.RegisterNamedAccount = channel.unary_unary(
                '/admin.AdminService/RegisterNamedAccount',
                request_serializer=admin__pb2.RegisterNamedAccountRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.RegisterBotAccount = channel.unary_unary(
                '/admin.AdminService/RegisterBotAccount',
                request_serializer=admin__pb2.RegisterBotAccountRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.AddPartition = channel.unary_unary(
                '/admin.AdminService/AddPartition',
                request_serializer=admin__pb2.AddPartitionRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.SendPrivateMessage = channel.unary_unary(
                '/admin.AdminService/SendPrivateMessage',
                request_serializer=admin__pb2.SendPrivateMessageRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.SendPublicMessage = channel.unary_unary(
                '/admin.AdminService/SendPublicMessage',
                request_serializer=admin__pb2.SendPublicMessageRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.GetPosition = channel.unary_unary(
                '/admin.AdminService/GetPosition',
                request_serializer=admin__pb2.GetPositionRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.UpsertUser = channel.unary_unary(
                '/admin.AdminService/UpsertUser',
                request_serializer=admin__pb2.UpsertUserRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.AddUserToAccount = channel.unary_unary(
                '/admin.AdminService/AddUserToAccount',
                request_serializer=admin__pb2.AddUserToAccountRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.ClearUserAccounts = channel.unary_unary(
                '/admin.AdminService/ClearUserAccounts',
                request_serializer=admin__pb2.ClearUserAccountsRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)
        self.DeleteUserFromAccount = channel.unary_unary(
                '/admin.AdminService/DeleteUserFromAccount',
                request_serializer=admin__pb2.DeleteUserFromAccountRequest.SerializeToString,
                response_deserializer=exchange__pb2.GenericResponse.FromString,
                _registered_method=True)


class AdminServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def AddAccountTypeToPartition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EndPartition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PausePartition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartPartition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SettlePartition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OpenExchange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CloseExchange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddSymbol(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetPosition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdjustPosition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAccountFee(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetEnableFee(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetPositionLimits(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterNamedAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterBotAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddPartition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendPrivateMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendPublicMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPosition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpsertUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddUserToAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearUserAccounts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUserFromAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AdminServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AddAccountTypeToPartition': grpc.unary_unary_rpc_method_handler(
                    servicer.AddAccountTypeToPartition,
                    request_deserializer=admin__pb2.AddAccountTypeToPartitionRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'EndPartition': grpc.unary_unary_rpc_method_handler(
                    servicer.EndPartition,
                    request_deserializer=admin__pb2.EndPartitionRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'PausePartition': grpc.unary_unary_rpc_method_handler(
                    servicer.PausePartition,
                    request_deserializer=admin__pb2.PausePartitionRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'StartPartition': grpc.unary_unary_rpc_method_handler(
                    servicer.StartPartition,
                    request_deserializer=admin__pb2.StartPartitionRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'SettlePartition': grpc.unary_unary_rpc_method_handler(
                    servicer.SettlePartition,
                    request_deserializer=admin__pb2.SettlePartitionRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'OpenExchange': grpc.unary_unary_rpc_method_handler(
                    servicer.OpenExchange,
                    request_deserializer=admin__pb2.OpenExchangeRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'CloseExchange': grpc.unary_unary_rpc_method_handler(
                    servicer.CloseExchange,
                    request_deserializer=admin__pb2.CloseExchangeRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'AddSymbol': grpc.unary_unary_rpc_method_handler(
                    servicer.AddSymbol,
                    request_deserializer=admin__pb2.AddSymbolRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'SetPosition': grpc.unary_unary_rpc_method_handler(
                    servicer.SetPosition,
                    request_deserializer=admin__pb2.SetPositionRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'AdjustPosition': grpc.unary_unary_rpc_method_handler(
                    servicer.AdjustPosition,
                    request_deserializer=admin__pb2.AdjustPositionRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'SetAccountFee': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAccountFee,
                    request_deserializer=admin__pb2.SetAccountFeeRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'SetEnableFee': grpc.unary_unary_rpc_method_handler(
                    servicer.SetEnableFee,
                    request_deserializer=admin__pb2.SetEnableFeeRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'SetPositionLimits': grpc.unary_unary_rpc_method_handler(
                    servicer.SetPositionLimits,
                    request_deserializer=admin__pb2.SetPositionLimitsRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'RegisterNamedAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterNamedAccount,
                    request_deserializer=admin__pb2.RegisterNamedAccountRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'RegisterBotAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterBotAccount,
                    request_deserializer=admin__pb2.RegisterBotAccountRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'AddPartition': grpc.unary_unary_rpc_method_handler(
                    servicer.AddPartition,
                    request_deserializer=admin__pb2.AddPartitionRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'SendPrivateMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.SendPrivateMessage,
                    request_deserializer=admin__pb2.SendPrivateMessageRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'SendPublicMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.SendPublicMessage,
                    request_deserializer=admin__pb2.SendPublicMessageRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'GetPosition': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPosition,
                    request_deserializer=admin__pb2.GetPositionRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'UpsertUser': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertUser,
                    request_deserializer=admin__pb2.UpsertUserRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'AddUserToAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.AddUserToAccount,
                    request_deserializer=admin__pb2.AddUserToAccountRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'ClearUserAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearUserAccounts,
                    request_deserializer=admin__pb2.ClearUserAccountsRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
            'DeleteUserFromAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUserFromAccount,
                    request_deserializer=admin__pb2.DeleteUserFromAccountRequest.FromString,
                    response_serializer=exchange__pb2.GenericResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.AdminService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('admin.AdminService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AdminService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def AddAccountTypeToPartition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/AddAccountTypeToPartition',
            admin__pb2.AddAccountTypeToPartitionRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def EndPartition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/EndPartition',
            admin__pb2.EndPartitionRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PausePartition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/PausePartition',
            admin__pb2.PausePartitionRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StartPartition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/StartPartition',
            admin__pb2.StartPartitionRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SettlePartition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/SettlePartition',
            admin__pb2.SettlePartitionRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def OpenExchange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/OpenExchange',
            admin__pb2.OpenExchangeRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CloseExchange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/CloseExchange',
            admin__pb2.CloseExchangeRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AddSymbol(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/AddSymbol',
            admin__pb2.AddSymbolRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetPosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/SetPosition',
            admin__pb2.SetPositionRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AdjustPosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/AdjustPosition',
            admin__pb2.AdjustPositionRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetAccountFee(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/SetAccountFee',
            admin__pb2.SetAccountFeeRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetEnableFee(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/SetEnableFee',
            admin__pb2.SetEnableFeeRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetPositionLimits(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/SetPositionLimits',
            admin__pb2.SetPositionLimitsRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegisterNamedAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/RegisterNamedAccount',
            admin__pb2.RegisterNamedAccountRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegisterBotAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/RegisterBotAccount',
            admin__pb2.RegisterBotAccountRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AddPartition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/AddPartition',
            admin__pb2.AddPartitionRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SendPrivateMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/SendPrivateMessage',
            admin__pb2.SendPrivateMessageRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SendPublicMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/SendPublicMessage',
            admin__pb2.SendPublicMessageRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/GetPosition',
            admin__pb2.GetPositionRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpsertUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/UpsertUser',
            admin__pb2.UpsertUserRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AddUserToAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/AddUserToAccount',
            admin__pb2.AddUserToAccountRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ClearUserAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/ClearUserAccounts',
            admin__pb2.ClearUserAccountsRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteUserFromAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.AdminService/DeleteUserFromAccount',
            admin__pb2.DeleteUserFromAccountRequest.SerializeToString,
            exchange__pb2.GenericResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from .client import Trader, Admin, Listener, OrderSide, OrderTif, Response, ResponseList
from .game import GameInterface, GameSymbolConfig
from .constants import CURRENCY

__all__ = ["Trader", "Admin", "Listener", "CURRENCY", "OrderSide", "OrderTif", "Response", "ResponseList", "GameInterface", "GameSymbolConfig"]


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: marketdata.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'marketdata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import exchange_pb2 as exchange__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10marketdata.proto\x12\nmarketdata\x1a\x0e\x65xchange.proto\"M\n\x0bTapeMessage\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\r\n\x05price\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\t\x12\x11\n\tissued_at\x18\x04 \x01(\t\"}\n\x0fOrderBookStatus\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12%\n\x04tape\x18\x02 \x03(\x0b\x32\x17.marketdata.TapeMessage\x12#\n\x04\x62ook\x18\x03 \x01(\x0b\x32\x15.marketdata.OrderBook\x12\x0e\n\x06volume\x18\x04 \x01(\t\"]\n\x0bPublicOrder\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\t\x12\r\n\x05price\x18\x03 \x01(\t\x12!\n\x04side\x18\x04 \x01(\x0e\x32\x13.exchange.OrderSide\"Y\n\tOrderBook\x12%\n\x04\x62ids\x18\x01 \x03(\x0b\x32\x17.marketdata.PublicOrder\x12%\n\x04\x61sks\x18\x02 \x03(\x0b\x32\x17.marketdata.PublicOrder\"7\n\x13SubscriptionRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t\"\x88\x01\n\x05Order\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x0f\n\x07logging\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\t\x12\r\n\x05price\x18\x05 \x01(\t\x12!\n\x04side\x18\x06 \x01(\x0e\x32\x13.exchange.OrderSide\x12\x12\n\ncreated_at\x18\x07 \x01(\t\"5\n\x10OpenOrdersStatus\x12!\n\x06orders\x18\x01 \x03(\x0b\x32\x11.marketdata.Order\"\x89\x01\n\x04\x46ill\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x10\n\x08order_id\x18\x02 \x01(\t\x12\x0e\n\x06symbol\x18\x03 \x01(\t\x12\r\n\x05price\x18\x04 \x01(\t\x12\x0c\n\x04size\x18\x05 \x01(\t\x12!\n\x04side\x18\x06 \x01(\x0e\x32\x13.exchange.OrderSide\x12\x11\n\tissued_at\x18\x07 \x01(\t\".\n\x0bRecentFills\x12\x1f\n\x05\x66ills\x18\x01 \x03(\x0b\x32\x10.marketdata.Fill\"8\n\x0e\x45xchangeStatus\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x16\n\x0emarket_symbols\x18\x02 \x03(\t\"\xc9\x03\n\nMarketData\x12\x30\n\torderbook\x18\x01 \x01(\x0b\x32\x1b.marketdata.OrderBookStatusH\x00\x12.\n\x06orders\x18\x02 \x01(\x0b\x32\x1c.marketdata.OpenOrdersStatusH\x00\x12-\n\tpositions\x18\x03 \x01(\x0b\x32\x18.exchange.PositionStatusH\x00\x12 \n\x04\x66ill\x18\x04 \x01(\x0b\x32\x10.marketdata.FillH\x00\x12/\n\x0crecent_fills\x18\x05 \x01(\x0b\x32\x17.marketdata.RecentFillsH\x00\x12\x35\n\x0f\x65xchange_status\x18\x06 \x01(\x0b\x32\x1a.marketdata.ExchangeStatusH\x00\x12-\n\x0epublic_message\x18\x07 \x01(\x0b\x32\x13.marketdata.MessageH\x00\x12.\n\x0fprivate_message\x18\x08 \x01(\x0b\x32\x13.marketdata.MessageH\x00\x12\x35\n\x0frecent_messages\x18\t \x01(\x0b\x32\x1a.marketdata.RecentMessagesH\x00\x42\n\n\x08response\";\n\x07Message\x12\x0f\n\x07is_priv\x18\x01 \x01(\x08\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x03 \x01(\t\"7\n\x0eRecentMessages\x12%\n\x08messages\x18\x01 \x03(\x0b\x32\x13.marketdata.Message2^\n\x11MarketDataService\x12I\n\x0cStreamStatus\x12\x1f.marketdata.SubscriptionRequest\x1a\x16.marketdata.MarketData0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'marketdata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TAPEMESSAGE']._serialized_start=48
  _globals['_TAPEMESSAGE']._serialized_end=125
  _globals['_ORDERBOOKSTATUS']._serialized_start=127
  _globals['_ORDERBOOKSTATUS']._serialized_end=252
  _globals['_PUBLICORDER']._serialized_start=254
  _globals['_PUBLICORDER']._serialized_end=347
  _globals['_ORDERBOOK']._serialized_start=349
  _globals['_ORDERBOOK']._serialized_end=438
  _globals['_SUBSCRIPTIONREQUEST']._serialized_start=440
  _globals['_SUBSCRIPTIONREQUEST']._serialized_end=495
  _globals['_ORDER']._serialized_start=498
  _globals['_ORDER']._serialized_end=634
  _globals['_OPENORDERSSTATUS']._serialized_start=636
  _globals['_OPENORDERSSTATUS']._serialized_end=689
  _globals['_FILL']._serialized_start=692
  _globals['_FILL']._serialized_end=829
  _globals['_RECENTFILLS']._serialized_start=831
  _globals['_RECENTFILLS']._serialized_end=877
  _globals['_EXCHANGESTATUS']._serialized_start=879
  _globals['_EXCHANGESTATUS']._serialized_end=935
  _globals['_MARKETDATA']._serialized_start=938
  _globals['_MARKETDATA']._serialized_end=1395
  _globals['_MESSAGE']._serialized_start=1397
  _globals['_MESSAGE']._serialized_end=1456
  _globals['_RECENTMESSAGES']._serialized_start=1458
  _globals['_RECENTMESSAGES']._serialized_end=1513
  _globals['_MARKETDATASERVICE']._serialized_start=1515
  _globals['_MARKETDATASERVICE']._serialized_end=1609
# @@protoc_insertion_point(module_scope)



from dataclasses import dataclass
from typing import Dict, List
from .client import Admin, OrderSide, OrderTif, PublicOrder, Trader, Listener
from abc import ABC, abstractmethod
from .constants import CURRENCY
from .protos import marketdata_pb2 as marketdata
import asyncio

import uuid

@dataclass
class GameSymbolConfig:
    initial_position: int
    lower_bound: float
    upper_bound: float

class GameInterface(ABC):
    def __init__(self, url: str, admin_account: str, api_key: str, id: str = None):
        self.url = url
        self.admin = Admin(account=admin_account, api_key=api_key, url=url)
        self.account_types = []
        if id == None:
            self.id = str(uuid.uuid4())
        else:
            self.id = id
        self.game_name = self.get_game_name()
        self.partition = self.game_name + self.id
        self.bot_account = "bot" + self.partition
        self.admin.register_bot_account(self.bot_account)
        self.bot = Trader(account=self.bot_account, api_key="bot", url=url)
        self.admin.set_position(self.bot_account, CURRENCY, 10000000000)
        self.bot_orders = set()
        self.orderbook = {}
        self.reset_orderbook()
    @abstractmethod
    def get_game_name(self) -> str:
        pass
    def bot_order(self, symbol: str, size: int, price: int, side: OrderSide, tif: OrderTif):
        response = self.bot.submit_order(symbol=symbol, size=size, price=price, side=side, tif=tif)
        id = response.message
        self.bot_orders.add(id)
        return response
    def bot_cancel(self, order_id: str):
        try:
            self.bot_orders.remove(order_id)
        except KeyError:
            pass
        return self.bot.cancel_order(order_id=order_id)
    def bot_cancel_all(self):
        ids = list(self.bot_orders)
        self.bot_orders.clear()
        return self.bot.cancel_orders(order_ids=ids)
    def get_symbols(self) -> List[str]:
        return list(self.get_symbol_config().keys())
    @abstractmethod
    def get_symbol_config(self) -> Dict[str, GameSymbolConfig]:
        pass
    @abstractmethod
    def get_initial_usd(self) -> int:
        pass
    def set_accounts(self, accounts: List[str]):
        self.accounts = accounts
    def init_account_positions(self, symbol: str, config: GameSymbolConfig):
        for account in self.accounts:
            self.admin.set_position(account, symbol, config.initial_position)
            self.admin.set_position_limits(account, symbol, config.lower_bound, config.upper_bound)
    def send_private_message(self, account: str, message: str):
        return self.admin.send_private_message(account, message)
    def send_public_message(self, message: str):
        return self.admin.send_public_message(self.partition, message)
    def start_game(self):
        self.admin.add_partition(self.partition)
        usd_pos = self.get_initial_usd()
        for account in self.accounts:
            self.admin.add_account_type_to_partition(self.partition, account)
            self.admin.set_position(account, CURRENCY, usd_pos)
        self.admin.add_account_type_to_partition(self.partition, self.bot_account)
        config = self.get_symbol_config()
        for symbol in config:
            self.admin.add_symbol(self.partition, self.name_to_id(symbol), symbol)
            self.init_account_positions(self.name_to_id(symbol), config[symbol])
            
        response = self.admin.start_partition(self.partition)
        print(response)
    def settle_game(self, settle_prices: Dict[str, int]):
        prices = {}
        for symbol in settle_prices:
            prices[self.name_to_id(symbol)] = settle_prices[symbol]
        return self.admin.settle_partition(self.partition, settle_prices=prices)
    @abstractmethod
    def game_body(self):
        pass
    @abstractmethod
    def game_settlement(self):
        pass
    def get_usd_positions(self) -> Dict[str, int]:
        pos = {}
        for account in self.accounts:
            pos[account] = self.admin.get_position(account, CURRENCY)
        return pos
    def name_to_id(self, symbol) -> str:
        return self.partition + symbol
    def reset_orderbook(self):
        config = self.get_symbol_config()
        for symbol in config:
            book = {}
            book['bids'] = []
            book['asks'] = []
            self.orderbook[symbol] = book
    async def listen(self):
        # Build your subscription request. Adjust fields as needed.
        listener = Listener(self.bot_account, api_key="bot", url=self.url)
        try:
            request = marketdata.SubscriptionRequest(
                api_key="bot",
                account=self.bot_account
            )

            # Calling the streaming RPC method.
            stream = listener.stub.StreamStatus(request)
            # Iterate over the stream of responses.
            async for market_data in stream:
                field = market_data.WhichOneof("response")
                if field == "orderbook":
                    orderbook = market_data.orderbook
                    symbol = orderbook.symbol
                    book = {}
                    book['bids'] = list(map(lambda x: PublicOrder(x.symbol, int(x.size), int(x.price)), orderbook.book.bids))
                    book['asks'] = list(map(lambda x: PublicOrder(x.symbol, int(x.size), int(x.price)), orderbook.book.asks))
                    self.orderbook[symbol] = book
        except asyncio.CancelledError:
            raise
    @abstractmethod
    def post_game_processing(self):
        pass
    async def run_game(self):
        self.start_game()
        task1 = asyncio.create_task(self.listen())
        # Run the synchronous run() in an executor.
        loop = asyncio.get_running_loop()
        await loop.run_in_executor(None, self.game_body)
        task1.cancel()
        try:
            await task1
        except asyncio.CancelledError:
            pass
        self.game_settlement()
        self.reset_orderbook()
        self.post_game_processing()
        
        


# setup.py
from setuptools import setup, find_packages

setup(
    name="huqtoracleclient",               # Package name
    version="0.3.8",                 # Version
    description="A Python package for interacting with the HUQT Oracle exchange programmatically",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    # author="Your Name",
    # author_email="your.email@example.com",
    # url="https://github.com/yourusername/my_package",  # Project URL
    packages=find_packages(),        # Automatically find packages in the directory
    include_package_data=True,
    classifiers=[                   # Optional metadata
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        "grpcio",         # Ensure version compatibility
        "grpcio-tools",
        "setuptools>=64", 
        "wheel",
        "certifi",
        # "protobuf>=3.X",      # Often not needed explicitly, but can be added if desired.
    ],
    python_requires=">=3.7",         # Minimum Python version
)


import asyncio
from huqt_oracle_client import client


# def run():
#     # Create a channel to the server at the given address (e.g., localhost:50051).
#     trader = client.Trader("account", "sigma", 'localhost:50051', secure=False)
#     trader2 = client.Trader("account2", "rigma", 'localhost:50051', secure=False)
    
#     # Prepare a request message
#     response = trader.submit_order(symbol = "BTC", size = 2, price = 100, side = 0, tif = 0)
#     print(response)
    
#     id = response.message
#     response = trader2.cancel_order(order_id = id)
#     print(response)
    
#     response = trader.cancel_order(order_id = id)
#     print(response)
    
#     response = trader.submit_order(symbol = "BTC", size = 2, price = 100, side = 0, tif = 0)
#     print(response)
    
#     ids = []
    
#     response = trader2.submit_order(symbol = "BTC", size = "2", price = "98", side = 1, tif = 0)
#     print(response)
    
#     ids.append(response.message)
    
#     response = trader2.submit_order(symbol = "BTC", size = "2", price = "98", side = 1, tif = 0)
#     print(response)
    
#     ids.append(response.message)
    
#     response = trader2.submit_order(symbol = "BTC", size = "2", price = "98", side = 1, tif = 0)
#     print(response)
    
#     ids.append(response.message)
    
#     response = trader.cancel_orders(order_ids = ids)
#     print(response)
    
#     response = trader2.cancel_orders(order_ids = ids)
#     print(response)
    
#     response = trader2.cancel_orders(order_ids = [])
#     print(response)
    
#     trader3 = client.Trader("account2", "trigma", 'localhost:50051', secure=False)
    
#     response = trader3.cancel_orders(order_ids = ids)
#     print(response)

# async def listen():
#     listener = client.Listener("account", "sigma", 'localhost:50051', secure=False)
#     await listener.listen()
    
# async def main():
#     # Run the asynchronous listener as a task.
#     task1 = asyncio.create_task(listen())
#     # Run the synchronous run() in an executor.
#     loop = asyncio.get_running_loop()
#     task2 = loop.run_in_executor(None, run)
#     await asyncio.gather(task1, task2)
    
def main():
    account = "account"
    admin = client.Admin(account, "sigma", 'huqt-oracle-rust.fly.dev:443', secure=True)
    partition = "BUMMA"
    response = admin.add_partition(partition)
    print(response)
    response = admin.add_symbol(partition, "BMM", "BMM")
    print(response)
    response = admin.start_partition(partition)
    print(response)
    response = admin.add_account_type_to_partition(partition, "admin")
    print(response)
    response = admin.send_public_message("crypto", "sigma")
    print(response)
    response = admin.send_private_message("benafan@mit.edu", "HI")
    print(response)
    # response = admin.set_position(account, "BMM", 10)
    # print(response)
    # response = admin.settle_partition(partition, settle_prices= {'BMM': 10})
    # print(response)
    # response = admin.
if __name__ == '__main__':
    # asyncio.run(main())
    main()